@@ -4,7 +4,6 @@ from oireachtas_nlp.models.text import TextBody
 
 
 class ExtendedParas(Paras):
-
     @property
     def text_obj(self):
-        return TextBody(content=' \n'.join([p.content for p in self.data]))
+        return TextBody(content=" \n".join([p.content for p in self.data]))
